@@ -2,15 +2,15 @@ from datetime import date, timedelta
 
 from kpler.sdk import Platform
 from kpler.sdk.configuration import Configuration
-from kpler.sdk.resources.trade import Trade
+from kpler.sdk.resources.trades import Trades
 
 
 config = Configuration(Platform.Liquids, "<your email>", "<your password>")
 
-trade_client = Trade(config)
+trades_client = Trades(config)
 
 # Get US imports over last week
-us_imports = trade_client.get(
+us_imports = trades_client.get(
     to_zones=["United States"],
     products=["crude"],
     with_forecast=False,
